import type { TUICallParam, TUIInitParam, TUIGroupCallParam, RemoteUser, CallbackParam, statusChangedReturnType, VideoResolution, ISelfInfoParams } from "./interface";
/**
 * class TUICallKit
 */
export default class TUICallKit {
    SDKAppID: number;
    tuiCallEngine: any;
    TUICore: any;
    version: string;
    beforeCalling: ((...args: any[]) => void) | undefined;
    afterCalling: ((...args: any[]) => void) | undefined;
    onMinimized: ((...args: any[]) => void) | undefined;
    onMessageSentByMe: ((...args: any[]) => void) | undefined;
    statusChanged: ((...args: any[]) => statusChangedReturnType) | undefined;
    error: any;
    tim: any;
    userID: string;
    constructor();
    /**
     * init 初始化
     * @param { TUIInitParam } params 初始化参数
     * @param { number } params.SDKAppID
     * @param { string } params.userID
     * @param { string } params.userSig
     * @param { any= } params.tim
     */
    init(params: TUIInitParam): Promise<void>;
    /**
     * call 呼叫
     * @param { TUICallParam } params 呼叫参数
     * @param { string } params.userID 被呼叫的用户
     * @param { number } params.type 呼叫类型 1-语音，2-视频
     * @param { number= } params.roomID 自定义数字房间号, 范围：[1, 2147483647]
     * @param { string= } params.userData 扩展字段: 用于在邀请信令中增加扩展信息
     * @param { number= } params.timeout 0为不超时, 单位 s(秒), 默认 30s
     * @param { offlinePushInfoType= } params.offlinePushInfo 自定义离线消息推送
     * @param { string= } params.offlinePushInfo.title 自定义离线消息推送
     * @param { string= } params.offlinePushInfo.description 自定义离线消息推送
     * @param { string= } params.offlinePushInfo.androidOPPOChannelID 自定义离线消息推送
     * @param { string= } params.offlinePushInfo.extension 自定义离线消息推送
     */
    call(params: TUICallParam): Promise<void>;
    /**
     * groupCall 呼叫
     * @param { TUIGroupCallParam } params 呼叫参数
     * @param { string } params.userIDList 被呼叫的用户列表
     * @param { number } params.type 呼叫类型 1-语音，2-视频
     * @param { string } params.groupID 呼叫群组ID
     * @param { number= } params.timeout 0为不超时, 单位 s(秒), 默认 30s
     * @param { number= } params.roomID 自定义数字房间号, 范围：[1, 2147483647]
     * @param { string= } params.userData 扩展字段: 用于在邀请信令中增加扩展信息
     * @param { offlinePushInfoType= } params.offlinePushInfo 自定义离线消息推送
     * @param { string= } params.offlinePushInfo.title 自定义离线消息推送
     * @param { string= } params.offlinePushInfo.description 自定义离线消息推送
     * @param { string= } params.offlinePushInfo.androidOPPOChannelID 自定义离线消息推送
     * @param { string= } params.offlinePushInfo.extension 自定义离线消息推送
     */
    groupCall(params: TUIGroupCallParam): Promise<void>;
    joinInGroupCall(params: any): Promise<void>;
    private checkStatus;
    updateCameraList(): Promise<void>;
    updateMicrophoneList(): Promise<void>;
    private setDefaultDevice;
    switchDevice(deviceType: string, deviceId: string): Promise<void>;
    bindTUICore(TUICore: any): void;
    setCallback(params: CallbackParam): void;
    setLanguage(language: string): void;
    toggleMinimize(): void;
    accept(): Promise<void>;
    reject(): Promise<void>;
    /**
     * @deprecated since sdk version 1.3.2
     */
    startLocalView(local: string): Promise<void>;
    /**
     * @deprecated since sdk version 1.3.2
     */
    stopLocalView(): Promise<void>;
    startRemoteView(userID: string): Promise<void>;
    stopRemoteView(userID: string): Promise<void>;
    hangup(): Promise<void>;
    renderLocal(): Promise<void>;
    renderRemoteWaitList(): Promise<void>;
    renderRemoteList(list: RemoteUser[]): Promise<void>;
    openCamera(videoViewDomID: string): Promise<void>;
    closeCamera(): Promise<void>;
    openMicrophone(): Promise<void>;
    closeMicrophone(): Promise<void>;
    setVideoQuality(videoProfile: VideoResolution): Promise<void>;
    switchCallMediaType(): Promise<void>;
    onStatusChanged(statusChanged: (...args: any[]) => statusChangedReturnType): void;
    setSelfInfo(params: ISelfInfoParams): Promise<void>;
    enableAIVoice(enable: boolean): Promise<void>;
    inviteUser(params: any): Promise<void>;
    getTim(): any;
    /**
     * component destroyed
     */
    destroyed(): Promise<void>;
    private getIntoCallingStatus;
    /**
     * /////////////////////////////////////////////////////////////////////////////////
     * //
     * //                                    TUICallEngine listener
     * //
     * /////////////////////////////////////////////////////////////////////////////////
     */
    private bindTIMEvent;
    private unbindTIMEvent;
    private handleError;
    private handleSDKReady;
    private handleKickedOut;
    private handleUserVideoAvailable;
    private handleUserAudioAvailable;
    private handleUserVoiceVolume;
    private handleInvited;
    private handleUserAccept;
    private handleUserEnter;
    private handleUserLeave;
    private handleReject;
    private handleNoResponse;
    private handleLineBusy;
    private handleCallingCancel;
    private handleCallingTimeOut;
    private handleCallingEnd;
    private handleCallTypeChanged;
    private handleMessageSentByMe;
}
