import { languageData } from "../locales/index";
import { getLanguage } from "./index";

const CLASS_PREFIX = 'trtc_autoplay';
const CLASS_MASK = `${CLASS_PREFIX}_mask`;
const CLASS_WRAPPER = `${CLASS_PREFIX}_wrapper`;
const CLASS_HEADER = `${CLASS_PREFIX}_header`;
const CLASS_CONTENT = `${CLASS_PREFIX}_content`;
const CLASS_ACTION_WRAPPER = `${CLASS_PREFIX}_action_wrapper`;
const CLASS_ACTION_QUESTION = `${CLASS_PREFIX}_question`;
const CLASS_ACTION_COLLAPSE = `${CLASS_PREFIX}_collapse`;
const CLASS_ACTION_CONFIRM = `${CLASS_PREFIX}_action_confirm`;
const CLASS_DETAIL = `${CLASS_PREFIX}_detail`;
const COLOR_BLUE = '#2473E8';

let isStyleAdded = false;
export const isDialogShowing = () => !!document.querySelector(`.${CLASS_WRAPPER}`);

const DETAIL_TEXT = '';

class AutoPlayDialog {
  content;
  dialogNode_;
  bodyPosition_;
  showDetail_;
  isCollapseClicked_;
  constructor({ content }) {
    this.dialogNode_ = null;
    this.bodyPosition_ = '';
    this.content = content;

    // 加载样式
    if (!isStyleAdded) {
      const style = document.createElement('style');
      style.innerHTML = `.${CLASS_MASK}{position:fixed;top:0;left:0;right:0;bottom:0;width:100vw;height:100vh;display:flex;justify-content:center;align-items:center;background:rgba(0,0,0,0.5);z-index:1500;}.${CLASS_MASK} div:not(.${CLASS_ACTION_WRAPPER}){display:block !important;}.${CLASS_WRAPPER}{padding:14px;background:#fff;border-radius:3px;box-shadow:0px 3px 15px #434343;border:1px solid #d1cfcf;max-width:500px;}.${CLASS_WRAPPER} a{color:${COLOR_BLUE};}.${CLASS_HEADER}{overflow:hidden;text-overflow:ellipsis;font-size:16px;font-weight:600;}.${CLASS_CONTENT}{margin:8px 0;}.${CLASS_ACTION_WRAPPER}{width:100%;display:flex !important;align-items:center;justify-content:right;float:right;}.${CLASS_ACTION_COLLAPSE}{margin-right:auto;cursor:pointer}.${CLASS_ACTION_QUESTION}{height:100%;line-height:16px;cursor:pointer;}.${CLASS_ACTION_CONFIRM}{margin-left:8px;color:#fff;background:${COLOR_BLUE};padding:4px 12px;outline:none;border:1px solid;border-radius:3px;font-weight:bold;}.${CLASS_ACTION_CONFIRM}:hover{opacity:0.9;}.${CLASS_ACTION_COLLAPSE},.${CLASS_ACTION_CONFIRM},.${CLASS_CONTENT},.${CLASS_ACTION_QUESTION}{font-size:14px;}@media screen and (max-width:750px){.${CLASS_WRAPPER}{width:80vw;}}`;
      document.head.appendChild(style);
      isStyleAdded = true;
    }

    this.showDetail_ = false;
    this.isCollapseClicked_ = false;
    this.addDiaLog();
  }

  createDiaLog() {
    const template = document.createElement('template');
    template.innerHTML = `<div class="${CLASS_MASK}"><div class='${CLASS_WRAPPER}'><div class='${CLASS_HEADER}'>${location.host}</div><div class='${CLASS_CONTENT}'>${this.content}</div><div class='${CLASS_DETAIL}' style="visibility:hidden;width:100%;height:0;font-size:12px;color:gray;">${DETAIL_TEXT}</div><div class='${CLASS_ACTION_WRAPPER}'></div></div></div>`.trim();

    const confirmButton = document.createElement('button');
    confirmButton.className = CLASS_ACTION_CONFIRM;
    confirmButton.innerText = languageData[getLanguage()]['confirm-tip'];
    confirmButton.onclick = this.onConfirm.bind(this);

    const node = template.content.firstChild;
    // @ts-ignore
    const actionWrapper = node?.querySelector(`.${CLASS_ACTION_WRAPPER}`);
    actionWrapper.appendChild(confirmButton);
    return node;
  }

  addDiaLog() {
    if (!isDialogShowing()) {
      this.dialogNode_ = this.createDiaLog();
      document.body.appendChild(this.dialogNode_);
      // 点击遮罩也可恢复播放
      this.dialogNode_.onclick = this.onConfirm.bind(this);
      // 点击弹框区域时，阻止点击事件冒泡，避免遮罩触发点击事件。
      this.dialogNode_.querySelector(`.${CLASS_WRAPPER}`).onclick = e => e.stopPropagation();
      // 显示 dialog 时，让页面无法滚动。
      this.bodyPosition_ = document.body.style.position;
      document.body.style.position = 'fixed';
    }
  }

  deleteDiaLog() {
    if (this.dialogNode_) {
      document.body.removeChild(this.dialogNode_);
      // 关闭 dialog，恢复页面可以正常滚动
      document.body.style.position = this.bodyPosition_;
      this.dialogNode_ = null;
    }
  }

  onConfirm() {
    this.deleteDiaLog();
  }

  onCollapseClick() {
    const detail = this.dialogNode_.querySelector(`.${CLASS_DETAIL}`);
    detail.style.visibility = `${this.showDetail_ ? 'hidden' : 'visible'}`;
    detail.style.height = `${this.showDetail_ ? 0 : 'fit-content'}`;
    this.showDetail_ = !this.showDetail_;
    this.isCollapseClicked_ = true;
  }
}

export default AutoPlayDialog;
